@@ -2,7 +2,7 @@ package WebService::HipChat;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.1001'; # VERSION
+our $VERSION = '0.1002'; # VERSION
 
 use Carp qw(croak);
 use MIME::Entity;
@@ -240,7 +240,7 @@ WebService::HipChat
 
 =head1 VERSION
 
-version 0.1001
+version 0.1002
 
 =head1 SYNOPSIS
 
@@ -680,13 +680,21 @@ Example:
 
 =over
 
-=item Chris C. <https://github.com/centreti>
+=item *
 
-=item Chris Hughes <https://github.com/chrisspang>
+Chris C. <L<https://github.com/centreti>>
 
-=item Ken-ichi Mito <https://github.com/mittyorz>
+=item *
 
-=item Tim Man <https://github.com/teebszet>
+Chris Hughes <L<https://github.com/chrisspang>>
+
+=item *
+
+Ken-ichi Mito <L<https://github.com/mittyorz>>
+
+=item *
+
+Tim Man <L<https://github.com/teebszet>>
 
 =back
 
